==> ah-formbuilder-1.0.61.tgz: package/es/components/toolbar/icons/FileUpload.js <==
import React from 'react';
export default (function (_ref) {
  var _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? '#fff' : _ref$fill,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? '100%' : _ref$width,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? '100%' : _ref$height,
      _ref$viewBox = _ref.viewBox,
      viewBox = _ref$viewBox === void 0 ? '0 0 32 32' : _ref$viewBox;
  return /*#__PURE__*/React.createElement("svg", {
    width: width,
    style: style,
    height: height,
    viewBox: viewBox,
    className: className,
    xmlns: "http://www.w3.org/2000/svg",
    xmlnsXlink: "http://www.w3.org/1999/xlink"
  }, /*#__PURE__*/React.createElement("g", {
    clipPath: "url(#clip0)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M24.4438 7.26259L17.4438 0.762586C17.2538 0.587086 16.9798 0.484711 16.6918 0.484711C16.4038 0.484711 16.1298 0.587086 15.9398 0.762586L8.93977 7.26259C8.68177 7.50309 8.61777 7.84271 8.78177 8.13359C8.94377 8.42284 9.29977 8.60971 9.69177 8.60971H13.6918V19.1722C13.6918 19.6207 14.1398 19.9847 14.6918 19.9847H18.6918C19.2438 19.9847 19.6918 19.6207 19.6918 19.1722V8.60971H23.6918C24.0838 8.60971 24.4398 8.42446 24.6018 8.13359C24.7638 7.84271 24.7038 7.50146 24.4438 7.26259Z",
    fill: "#3C4858"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.6895 18.3597V23.2347H5.68945V18.3597H1.68945V24.8597C1.68945 25.7583 2.58545 26.4847 3.68945 26.4847H29.6895C30.7955 26.4847 31.6895 25.7583 31.6895 24.8597V18.3597H27.6895Z",
    fill: "#3C4858"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("clipPath", {
    id: "clip0"
  }, /*#__PURE__*/React.createElement("rect", {
    x: "0.689697",
    y: "0.484711",
    width: "32",
    height: "26",
    fill: "white"
  }))));
});

==> ah-formbuilder-1.0.92.tgz: package/es/components/toolbar/icons/FileUpload.js <==
var _this = this,
    _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/toolbar/icons/FileUpload.js";

import React from 'react';
export default (function (_ref) {
  var _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style,
      _ref$fill = _ref.fill,
      fill = _ref$fill === void 0 ? '#fff' : _ref$fill,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? '100%' : _ref$width,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? '100%' : _ref$height,
      _ref$viewBox = _ref.viewBox,
      viewBox = _ref$viewBox === void 0 ? '0 0 32 32' : _ref$viewBox;
  return /*#__PURE__*/React.createElement("svg", {
    width: width,
    style: style,
    height: height,
    viewBox: viewBox,
    className: className,
    xmlns: "http://www.w3.org/2000/svg",
    xmlnsXlink: "http://www.w3.org/1999/xlink",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 11,
      columnNumber: 3
    }
  }, /*#__PURE__*/React.createElement("g", {
    clipPath: "url(#clip0)",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement("path", {
    d: "M24.4438 7.26259L17.4438 0.762586C17.2538 0.587086 16.9798 0.484711 16.6918 0.484711C16.4038 0.484711 16.1298 0.587086 15.9398 0.762586L8.93977 7.26259C8.68177 7.50309 8.61777 7.84271 8.78177 8.13359C8.94377 8.42284 9.29977 8.60971 9.69177 8.60971H13.6918V19.1722C13.6918 19.6207 14.1398 19.9847 14.6918 19.9847H18.6918C19.2438 19.9847 19.6918 19.6207 19.6918 19.1722V8.60971H23.6918C24.0838 8.60971 24.4398 8.42446 24.6018 8.13359C24.7638 7.84271 24.7038 7.50146 24.4438 7.26259Z",
    fill: "#3C4858",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 21,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement("path", {
    d: "M27.6895 18.3597V23.2347H5.68945V18.3597H1.68945V24.8597C1.68945 25.7583 2.58545 26.4847 3.68945 26.4847H29.6895C30.7955 26.4847 31.6895 25.7583 31.6895 24.8597V18.3597H27.6895Z",
    fill: "#3C4858",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 22,
      columnNumber: 7
    }
  })), /*#__PURE__*/React.createElement("defs", {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 24,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement("clipPath", {
    id: "clip0",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 25,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement("rect", {
    x: "0.689697",
    y: "0.484711",
    width: "32",
    height: "26",
    fill: "white",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 26,
      columnNumber: 9
    }
  }))));
});
